# 2021-08-11 - Merkle Redeem for LDO rewards

Distributor contract for LDO rewards.

## Useful Files

- [Ethereum mainnet address](./output/mainnet.json)
- [`MerkleRedeem` ABI](./abi/MerkleRedeem.json)
